# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PTSL.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nPTSL.proto\x12\x04ptsl\"\x0e\n\x0c\x45mptyMessage\"u\n\x0c\x43ommandError\x12\x32\n\x12\x63ommand_error_type\x18\x01 \x01(\x0e\x32\x16.ptsl.CommandErrorType\x12\x1d\n\x15\x63ommand_error_message\x18\x02 \x01(\t\x12\x12\n\nis_warning\x18\x03 \x01(\x08\"g\n\rRequestHeader\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12 \n\x07\x63ommand\x18\x02 \x01(\x0e\x32\x0f.ptsl.CommandId\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x12\n\nsession_id\x18\x04 \x01(\t\"I\n\x07Request\x12#\n\x06header\x18\x01 \x01(\x0b\x32\x13.ptsl.RequestHeader\x12\x19\n\x11request_body_json\x18\x02 \x01(\t\"w\n\x0eResponseHeader\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12 \n\x07\x63ommand\x18\x02 \x01(\x0e\x32\x0f.ptsl.CommandId\x12 \n\x06status\x18\x03 \x01(\x0e\x32\x10.ptsl.TaskStatus\x12\x10\n\x08progress\x18\x04 \x01(\x05\"i\n\x08Response\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.ptsl.ResponseHeader\x12\x1a\n\x12response_body_json\x18\x02 \x01(\t\x12\x1b\n\x13response_error_json\x18\x03 \x01(\t\":\n\nPagination\x12\r\n\x05total\x18\x01 \x01(\x05\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05\"\xb2\x03\n\x0fTrackAttributes\x12.\n\x0bis_inactive\x18\x01 \x01(\x0e\x32\x19.ptsl.TrackAttributeState\x12,\n\tis_hidden\x18\x02 \x01(\x0e\x32\x19.ptsl.TrackAttributeState\x12.\n\x0bis_selected\x18\x03 \x01(\x0e\x32\x19.ptsl.TrackAttributeState\x12\x16\n\x0e\x63ontains_clips\x18\x04 \x01(\x08\x12\x1b\n\x13\x63ontains_automation\x18\x05 \x01(\x08\x12\x11\n\tis_soloed\x18\x06 \x01(\x08\x12\x19\n\x11is_record_enabled\x18\x07 \x01(\x08\x12\x39\n\x16is_input_monitoring_on\x18\x08 \x01(\x0e\x32\x19.ptsl.TrackAttributeState\x12\x17\n\x0fis_smart_dsp_on\x18\t \x01(\x08\x12\x11\n\tis_locked\x18\n \x01(\x08\x12\x10\n\x08is_muted\x18\x0b \x01(\x08\x12\x11\n\tis_frozen\x18\x0c \x01(\x08\x12\x0f\n\x07is_open\x18\r \x01(\x08\x12\x11\n\tis_online\x18\x0e \x01(\x08\"\xa6\x01\n\x05Track\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\x04type\x18\x02 \x01(\x0e\x32\x0f.ptsl.TrackType\x12\n\n\x02id\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05\x63olor\x18\x05 \x01(\t\x12/\n\x10track_attributes\x18\x06 \x01(\x0b\x32\x15.ptsl.TrackAttributes\x12\x15\n\rid_compressed\x18\x07 \x01(\t\"+\n\x18GetTaskStatusRequestBody\x12\x0f\n\x07task_id\x18\x01 \x01(\t\"`\n\x19GetTaskStatusResponseBody\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12 \n\x06status\x18\x02 \x01(\x0e\x32\x10.ptsl.TaskStatus\x12\x10\n\x08progress\x18\x03 \x01(\x05\"\x95\x03\n\x18\x43reateSessionRequestBody\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x1c\n\x14\x63reate_from_template\x18\x02 \x01(\x08\x12\x16\n\x0etemplate_group\x18\x03 \x01(\t\x12\x15\n\rtemplate_name\x18\x04 \x01(\t\x12!\n\tfile_type\x18\x05 \x01(\x0e\x32\x0e.ptsl.FileType\x12%\n\x0bsample_rate\x18\x06 \x01(\x0e\x32\x10.ptsl.SampleRate\x12/\n\x15input_output_settings\x18\x07 \x01(\x0e\x32\x10.ptsl.IOSettings\x12\x16\n\x0eis_interleaved\x18\x08 \x01(\x08\x12\x18\n\x10session_location\x18\t \x01(\t\x12\x18\n\x10is_cloud_project\x18\n \x01(\x08\x12\x17\n\x0f\x63reate_from_aaf\x18\x0b \x01(\x08\x12\x13\n\x0bpath_to_aaf\x18\x0c \x01(\t\x12!\n\tbit_depth\x18\r \x01(\x0e\x32\x0e.ptsl.BitDepth\".\n\x16OpenSessionRequestBody\x12\x14\n\x0csession_path\x18\x01 \x01(\t\"z\n\x11TrackDataToImport\x12\x1e\n\x16track_data_preset_path\x18\x01 \x01(\t\x12\x11\n\tclip_gain\x18\x02 \x01(\x08\x12\x17\n\x0f\x63lips_and_media\x18\x03 \x01(\x08\x12\x19\n\x11volume_automation\x18\x04 \x01(\x08\"\xc6\x01\n\x11SessionDataImport\x12\x17\n\x0ftempo_meter_map\x18\x01 \x01(\x08\x12\x1f\n\x17key_signature_choed_map\x18\x02 \x01(\x08\x12 \n\x18markers_memory_locations\x18\x03 \x01(\x08\x12\x1d\n\x15window_configurations\x18\x04 \x01(\x08\x12\x18\n\x10mic_pre_settings\x18\x05 \x01(\x08\x12\x1c\n\x14heat_master_settings\x18\x06 \x01(\x08\"\xba\x03\n\x0bSessionData\x12.\n\raudio_options\x18\x01 \x01(\x0e\x32\x17.ptsl.AudioMediaOptions\x12\x19\n\x11\x61udio_handle_size\x18\x02 \x01(\x05\x12.\n\rvideo_options\x18\x03 \x01(\x0e\x32\x17.ptsl.VideoMediaOptions\x12.\n\rmatch_options\x18\x04 \x01(\x0e\x32\x17.ptsl.MatchTrackOptions\x12\x33\n\x10playlist_options\x18\x05 \x01(\x0e\x32\x19.ptsl.MainPlaylistOptions\x12\x35\n\x14track_data_to_import\x18\x06 \x01(\x0b\x32\x17.ptsl.TrackDataToImport\x12<\n\x16timecode_mapping_units\x18\x07 \x01(\x0e\x32\x1c.ptsl.TimeCodeMappingOptions\x12#\n\x1btimecode_mapping_start_time\x18\x08 \x01(\t\x12\x31\n)adjust_session_start_time_to_match_source\x18\t \x01(\x08\"\x8d\x01\n\x10SpotLocationData\x12-\n\rlocation_type\x18\x01 \x01(\x0e\x32\x16.ptsl.SpotLocationType\x12\x16\n\x0elocation_value\x18\x02 \x01(\t\x12\x32\n\x10location_options\x18\x03 \x01(\x0e\x32\x18.ptsl.TrackOffsetOptions\"\xec\x01\n\tAudioData\x12\x11\n\tfile_list\x18\x01 \x03(\t\x12/\n\x10\x61udio_operations\x18\x02 \x01(\x0e\x32\x15.ptsl.AudioOperations\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12+\n\x0b\x64\x65stination\x18\x04 \x01(\x0e\x32\x16.ptsl.MediaDestination\x12%\n\x08location\x18\x05 \x01(\x0e\x32\x13.ptsl.MediaLocation\x12-\n\rlocation_data\x18\x06 \x01(\x0b\x32\x16.ptsl.SpotLocationData\"\x0b\n\tVideoData\"\n\n\x08MidiData\"\x10\n\x0e\x43lipGroupsData\"\x9e\x01\n\x11ImportRequestBody\x12\x14\n\x0csession_path\x18\x01 \x01(\t\x12%\n\x0bimport_type\x18\x02 \x01(\x0e\x32\x10.ptsl.ImportType\x12\'\n\x0csession_data\x18\x03 \x01(\x0b\x32\x11.ptsl.SessionData\x12#\n\naudio_data\x18\x04 \x01(\x0b\x32\x0f.ptsl.AudioData\"r\n\x12ImportResponseBody\x12\x11\n\tfile_list\x18\x01 \x03(\t\x12/\n\x10\x61udio_operations\x18\x02 \x01(\x0e\x32\x15.ptsl.AudioOperations\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\"W\n\x19TrackListInvertibleFilter\x12%\n\x06\x66ilter\x18\x01 \x01(\x0e\x32\x15.ptsl.TrackListFilter\x12\x13\n\x0bis_inverted\x18\x02 \x01(\x08\"\x8a\x01\n\x17GetTrackListRequestBody\x12\x12\n\npage_limit\x18\x01 \x01(\x05\x12:\n\x11track_filter_list\x18\x02 \x03(\x0b\x32\x1f.ptsl.TrackListInvertibleFilter\x12\x1f\n\x17is_filter_list_additive\x18\x03 \x01(\x08\"\\\n\x18GetTrackListResponseBody\x12\x1f\n\x05stats\x18\x01 \x01(\x0b\x32\x10.ptsl.Pagination\x12\x1f\n\ntrack_list\x18\x02 \x03(\x0b\x32\x0b.ptsl.Track\"6\n SelectAllClipsOnTrackRequestBody\x12\x12\n\ntrack_name\x18\x01 \x01(\t\"7\n!SelectAllClipsOnTrackResponseBody\x12\x12\n\ntrack_name\x18\x01 \x01(\t\"G\n(ExtendSelectionToTargetTracksRequestBody\x12\x1b\n\x13tracks_to_extend_to\x18\x01 \x03(\t\"H\n)ExtendSelectionToTargetTracksResponseBody\x12\x1b\n\x13tracks_to_extend_to\x18\x01 \x03(\t\"[\n#CreateFadesBasedOnPresetRequestBody\x12\x18\n\x10\x66\x61\x64\x65_preset_name\x18\x01 \x01(\t\x12\x1a\n\x12\x61uto_adjust_bounds\x18\x02 \x01(\x08\"@\n$CreateFadesBasedOnPresetResponseBody\x12\x18\n\x10\x66\x61\x64\x65_preset_name\x18\x01 \x01(\t\"X\n\x1cRenameTargetTrackRequestBody\x12\x10\n\x08track_id\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\x12\x14\n\x0c\x63urrent_name\x18\x03 \x01(\t\"\xfe\x01\n\x1d\x45xportClipsAsFilesRequestBody\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12\"\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x12.ptsl.ExportFormat\x12\'\n\tfile_type\x18\x03 \x01(\x0e\x32\x14.ptsl.ExportFileType\x12!\n\tbit_depth\x18\x04 \x01(\x0e\x32\x0e.ptsl.BitDepth\x12\x36\n\x0f\x64uplicate_names\x18\x05 \x01(\x0e\x32\x1d.ptsl.ResolveDuplicateNamesBy\x12\"\n\x1a\x65nforce_avid_compatibility\x18\x06 \x01(\x08\"\xad\x03\n\'ExportSelectedTracksAsAAFOMFRequestBody\x12,\n\tfile_type\x18\x02 \x01(\x0e\x32\x19.ptsl.ExportAsAAFFileType\x12(\n\tbit_depth\x18\x03 \x01(\x0e\x32\x15.ptsl.AAFFileBitDepth\x12%\n\x0b\x63opy_option\x18\x04 \x01(\x0e\x32\x10.ptsl.CopyOption\x12,\n$enforce_media_composer_compatibility\x18\x05 \x01(\x08\x12*\n\"quantize_edits_to_frame_boundaries\x18\x06 \x01(\x08\x12%\n\x1d\x65xport_stereo_as_multichannel\x18\x07 \x01(\x08\x12\x1b\n\x13\x63ontainer_file_name\x18\t \x01(\t\x12\x1f\n\x17\x63ontainer_file_location\x18\n \x01(\t\x12\x1b\n\x13\x61sset_file_location\x18\x0b \x01(\t\x12\x10\n\x08\x63omments\x18\x0c \x01(\t\x12\x15\n\rsequence_name\x18\r \x01(\t\"7\n\"RefreshTargetAudioFilesRequestBody\x12\x11\n\tfile_list\x18\x01 \x03(\t\"i\n#RefreshTargetAudioFilesResponseBody\x12\x15\n\rsuccess_count\x18\x01 \x01(\x05\x12\x15\n\rfailure_count\x18\x02 \x01(\x05\x12\x14\n\x0c\x66\x61ilure_list\x18\x03 \x03(\t\"%\n\x10\x46ileLocationInfo\x12\x11\n\tis_online\x18\x01 \x01(\x08\"B\n\x0c\x46ileLocation\x12\x0c\n\x04path\x18\x01 \x01(\t\x12$\n\x04info\x18\x02 \x01(\x0b\x32\x16.ptsl.FileLocationInfo\"d\n\x1aGetFileLocationRequestBody\x12\x12\n\npage_limit\x18\x01 \x01(\x05\x12\x32\n\x0c\x66ile_filters\x18\x02 \x03(\x0e\x32\x1c.ptsl.FileLocationTypeFilter\"j\n\x1bGetFileLocationResponseBody\x12\x1f\n\x05stats\x18\x01 \x01(\x0b\x32\x10.ptsl.Pagination\x12*\n\x0e\x66ile_locations\x18\x02 \x03(\x0b\x32\x12.ptsl.FileLocation\"0\n\x17\x43loseSessionRequestBody\x12\x15\n\rsave_on_close\x18\x01 \x01(\x08\"J\n\x18SaveSessionAsRequestBody\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x18\n\x10session_location\x18\x02 \x01(\t\"T\n\x15\x43utSpecialRequestBody\x12;\n\x16\x61utomation_data_option\x18\x01 \x01(\x0e\x32\x1b.ptsl.AutomationDataOptions\"U\n\x16\x43opySpecialRequestBody\x12;\n\x16\x61utomation_data_option\x18\x01 \x01(\x0e\x32\x1b.ptsl.AutomationDataOptions\"V\n\x17\x43learSpecialRequestBody\x12;\n\x16\x61utomation_data_option\x18\x01 \x01(\x0e\x32\x1b.ptsl.AutomationDataOptions\"R\n\x17PasteSpecialRequestBody\x12\x37\n\x14paste_special_option\x18\x01 \x01(\x0e\x32\x19.ptsl.PasteSpecialOptions\"G\n\rEM_SourceInfo\x12(\n\x0bsource_type\x18\x01 \x01(\x0e\x32\x13.ptsl.EM_SourceType\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x97\x02\n\x0c\x45M_AudioInfo\x12/\n\x10\x63ompression_type\x18\x01 \x01(\x0e\x32\x15.ptsl.CompressionType\x12)\n\rexport_format\x18\x02 \x01(\x0e\x32\x12.ptsl.ExportFormat\x12!\n\tbit_depth\x18\x03 \x01(\x0e\x32\x0e.ptsl.BitDepth\x12%\n\x0bsample_rate\x18\x04 \x01(\x0e\x32\x10.ptsl.SampleRate\x12/\n\x15pad_to_frame_boundary\x18\x05 \x01(\x0e\x32\x10.ptsl.TripleBool\x12\x30\n\x0f\x64\x65livery_format\x18\x06 \x01(\x0e\x32\x17.ptsl.EM_DeliveryFormat\"]\n\x11PropertyContainer\x12\x16\n\x0e\x63ontainer_name\x18\x01 \x01(\t\x12!\n\x04type\x18\x02 \x01(\x0e\x32\x13.ptsl.DP_ValueTypes\x12\r\n\x05value\x18\x03 \x01(\t\"R\n\x0c\x45M_CodecInfo\x12\x12\n\ncodec_name\x18\x01 \x01(\t\x12.\n\rproperty_list\x18\x02 \x03(\x0b\x32\x17.ptsl.PropertyContainer\"\xc5\x01\n\x0c\x45M_VideoInfo\x12\'\n\rinclude_video\x18\x01 \x01(\x0e\x32\x10.ptsl.TripleBool\x12\x32\n\rexport_option\x18\x02 \x01(\x0e\x32\x1b.ptsl.EM_VideoExportOptions\x12\x30\n\x16replace_timecode_track\x18\x03 \x01(\x0e\x32\x10.ptsl.TripleBool\x12&\n\ncodec_info\x18\x04 \x01(\x0b\x32\x12.ptsl.EM_CodecInfo\"\xf3\x02\n\x10\x45M_ImportOptions\x12\x32\n\x12import_destination\x18\x01 \x01(\x0e\x32\x16.ptsl.MediaDestination\x12,\n\x0fimport_location\x18\x02 \x01(\x0e\x32\x13.ptsl.MediaLocation\x12\x1a\n\x12gaps_between_clips\x18\x03 \x01(\x05\x12\x30\n\x16import_audio_from_file\x18\x04 \x01(\x0e\x32\x10.ptsl.TripleBool\x12\x36\n\x1cremove_existing_video_tracks\x18\x05 \x01(\x0e\x32\x10.ptsl.TripleBool\x12\x35\n\x1bremove_existing_video_clips\x18\x06 \x01(\x0e\x32\x10.ptsl.TripleBool\x12@\n&clear_destination_video_track_playlist\x18\x07 \x01(\x0e\x32\x10.ptsl.TripleBool\"\xb7\x01\n\x0f\x45M_LocationInfo\x12-\n\x13import_after_bounce\x18\x01 \x01(\x0e\x32\x10.ptsl.TripleBool\x12.\n\x0eimport_options\x18\x02 \x01(\x0b\x32\x16.ptsl.EM_ImportOptions\x12\x32\n\x10\x66ile_destination\x18\x03 \x01(\x0e\x32\x18.ptsl.EM_FileDestination\x12\x11\n\tdirectory\x18\x04 \x01(\t\"\xa4\x01\n\x11\x45M_DolbyAtmosInfo\x12\x33\n\x19\x61\x64\x64_first_frame_of_action\x18\x01 \x01(\x0e\x32\x10.ptsl.TripleBool\x12\x16\n\x0etimecode_value\x18\x02 \x01(\t\x12\x12\n\nframe_rate\x18\x03 \x01(\x05\x12.\n\rproperty_list\x18\x04 \x03(\x0b\x32\x17.ptsl.PropertyContainer\"\x96\x03\n\x14\x45xportMixRequestBody\x12\x13\n\x0bpreset_path\x18\x01 \x01(\t\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12$\n\tfile_type\x18\x03 \x01(\x0e\x32\x11.ptsl.EM_FileType\x12\'\n\nfiles_list\x18\x04 \x03(\x0b\x32\x13.ptsl.EM_SourceInfo\x12&\n\naudio_info\x18\x05 \x01(\x0b\x32\x12.ptsl.EM_AudioInfo\x12&\n\nvideo_info\x18\x06 \x01(\x0b\x32\x12.ptsl.EM_VideoInfo\x12,\n\rlocation_info\x18\x07 \x01(\x0b\x32\x15.ptsl.EM_LocationInfo\x12\x31\n\x10\x64olby_atmos_info\x18\x08 \x01(\x0b\x32\x17.ptsl.EM_DolbyAtmosInfo\x12(\n\x0eoffline_bounce\x18\t \x01(\x0e\x32\x10.ptsl.TripleBool\x12,\n\x0fmix_source_list\x18\n \x03(\x0b\x32\x13.ptsl.EM_SourceInfo\"\xd5\x01\n\x12PropertyDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\'\n\nvalue_type\x18\x02 \x01(\x0e\x32\x13.ptsl.DP_ValueTypes\x12\x13\n\x0bobject_type\x18\x03 \x01(\t\x12\x10\n\x08required\x18\x04 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\r\n\x05units\x18\x06 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pted_values\x18\x07 \x03(\t\x12\x11\n\tmax_value\x18\x08 \x01(\t\x12\x11\n\tmin_value\x18\t \x01(\t\"S\n\x1fGetDynamicPropertiesRequestBody\x12\x30\n\rproperty_type\x18\x01 \x01(\x0e\x32\x19.ptsl.DynamicPropertyType\"w\n\x19GetDynamicPropertiesGroup\x12)\n\x08key_list\x18\x01 \x03(\x0b\x32\x17.ptsl.PropertyContainer\x12/\n\rproperty_list\x18\x02 \x03(\x0b\x32\x18.ptsl.PropertyDescriptor\"\x89\x01\n GetDynamicPropertiesResponseBody\x12\x30\n\rproperty_type\x18\x01 \x01(\x0e\x32\x19.ptsl.DynamicPropertyType\x12\x33\n\ngroup_list\x18\x02 \x03(\x0b\x32\x1f.ptsl.GetDynamicPropertiesGroup\"x\n\x0fSpotRequestBody\x12\x36\n\x14track_offset_options\x18\x01 \x01(\x0e\x32\x18.ptsl.TrackOffsetOptions\x12-\n\rlocation_data\x18\x02 \x01(\x0b\x32\x16.ptsl.SpotLocationData\"\xf5\x03\n\"ExportSessionInfoAsTextRequestBody\x12\x19\n\x11include_file_list\x18\x01 \x01(\x08\x12\x19\n\x11include_clip_list\x18\x02 \x01(\x08\x12\x17\n\x0finclude_markers\x18\x03 \x01(\x08\x12\x1b\n\x13include_plugin_list\x18\x04 \x01(\x08\x12\x1a\n\x12include_track_edls\x18\x05 \x01(\x08\x12\x17\n\x0fshow_sub_frames\x18\x06 \x01(\x08\x12\x1f\n\x17include_user_timestamps\x18\x07 \x01(\x08\x12,\n\x0ftrack_list_type\x18\x08 \x01(\x0e\x32\x13.ptsl.TrackListType\x12\x32\n\x12\x66\x61\x64\x65_handling_type\x18\t \x01(\x0e\x32\x16.ptsl.FadeHandlingType\x12\x36\n\x14track_offset_options\x18\n \x01(\x0e\x32\x18.ptsl.TrackOffsetOptions\x12\x33\n\x13text_as_file_format\x18\x0b \x01(\x0e\x32\x16.ptsl.TextAsFileFormat\x12)\n\x0boutput_type\x18\x0c \x01(\x0e\x32\x14.ptsl.ESI_OutputType\x12\x13\n\x0boutput_path\x18\r \x01(\t\";\n#ExportSessionInfoAsTextResponseBody\x12\x14\n\x0csession_info\x18\x01 \x01(\t\"J\n\x1aSetPlaybackModeRequestBody\x12,\n\rplayback_mode\x18\x01 \x01(\x0e\x32\x15.ptsl.PM_PlaybackMode\"\x86\x01\n\x1bSetPlaybackModeResponseBody\x12\x34\n\x15\x63urrent_playback_mode\x18\x01 \x01(\x0e\x32\x15.ptsl.PM_PlaybackMode\x12\x31\n\x12playback_mode_list\x18\x02 \x03(\x0e\x32\x15.ptsl.PM_PlaybackMode\"b\n\x18SetRecordModeRequestBody\x12(\n\x0brecord_mode\x18\x01 \x01(\x0e\x32\x13.ptsl.RM_RecordMode\x12\x1c\n\x14record_arm_transport\x18\x02 \x01(\x08\"|\n\x19SetRecordModeResponseBody\x12\x30\n\x13\x63urrent_record_mode\x18\x01 \x01(\x0e\x32\x13.ptsl.RM_RecordMode\x12-\n\x10record_mode_list\x18\x02 \x03(\x0e\x32\x13.ptsl.RM_RecordMode\"\x8b\x01\n!GetSessionAudioFormatResponseBody\x12\x31\n\x0f\x63urrent_setting\x18\x01 \x01(\x0e\x32\x18.ptsl.SessionAudioFormat\x12\x33\n\x11possible_settings\x18\x02 \x03(\x0e\x32\x18.ptsl.SessionAudioFormat\"I\n GetSessionSampleRateResponseBody\x12%\n\x0bsample_rate\x18\x01 \x01(\x0e\x32\x10.ptsl.SampleRate\"t\n\x1eGetSessionBitDepthResponseBody\x12\'\n\x0f\x63urrent_setting\x18\x01 \x01(\x0e\x32\x0e.ptsl.BitDepth\x12)\n\x11possible_settings\x18\x02 \x03(\x0e\x32\x0e.ptsl.BitDepth\"\\\n&GetSessionInterleavedStateResponseBody\x12\x17\n\x0f\x63urrent_setting\x18\x01 \x01(\x08\x12\x19\n\x11possible_settings\x18\x02 \x03(\x08\"\x8e\x01\n\"GetSessionTimeCodeRateResponseBody\x12\x32\n\x0f\x63urrent_setting\x18\x01 \x01(\x0e\x32\x19.ptsl.SessionTimeCodeRate\x12\x34\n\x11possible_settings\x18\x02 \x03(\x0e\x32\x19.ptsl.SessionTimeCodeRate\"\x94\x01\n$GetSessionFeetFramesRateResponseBody\x12\x34\n\x0f\x63urrent_setting\x18\x01 \x01(\x0e\x32\x1b.ptsl.SessionFeetFramesRate\x12\x36\n\x11possible_settings\x18\x02 \x03(\x0e\x32\x1b.ptsl.SessionFeetFramesRate\"\x8f\x01\n+GetSessionAudioRatePullSettingsResponseBody\x12.\n\x0f\x63urrent_setting\x18\x01 \x01(\x0e\x32\x15.ptsl.SessionRatePull\x12\x30\n\x11possible_settings\x18\x02 \x03(\x0e\x32\x15.ptsl.SessionRatePull\"\x8f\x01\n+GetSessionVideoRatePullSettingsResponseBody\x12.\n\x0f\x63urrent_setting\x18\x01 \x01(\x0e\x32\x15.ptsl.SessionRatePull\x12\x30\n\x11possible_settings\x18\x02 \x03(\x0e\x32\x15.ptsl.SessionRatePull\"2\n\x1aGetSessionNameResponseBody\x12\x14\n\x0csession_name\x18\x01 \x01(\t\"F\n\x1aGetSessionPathResponseBody\x12(\n\x0csession_path\x18\x01 \x01(\x0b\x32\x12.ptsl.FileLocation\"=\n\x1fGetSessionStartTimeResponseBody\x12\x1a\n\x12session_start_time\x18\x01 \x01(\t\"6\n\x1cGetSessionLengthResponseBody\x12\x16\n\x0esession_length\x18\x01 \x01(\t\"R\n SetSessionAudioFormatRequestBody\x12.\n\x0c\x61udio_format\x18\x01 \x01(\x0e\x32\x18.ptsl.SessionAudioFormat\"B\n\x1dSetSessionBitDepthRequestBody\x12!\n\tbit_depth\x18\x01 \x01(\x0e\x32\x0e.ptsl.BitDepth\"B\n%SetSessionInterleavedStateRequestBody\x12\x19\n\x11interleaved_state\x18\x01 \x01(\x08\"V\n!SetSessionTimeCodeRateRequestBody\x12\x31\n\x0etime_code_rate\x18\x01 \x01(\x0e\x32\x19.ptsl.SessionTimeCodeRate\"\\\n#SetSessionFeetFramesRateRequestBody\x12\x35\n\x10\x66\x65\x65t_frames_rate\x18\x01 \x01(\x0e\x32\x1b.ptsl.SessionFeetFramesRate\"\\\n*SetSessionAudioRatePullSettingsRequestBody\x12.\n\x0f\x61udio_rate_pull\x18\x01 \x01(\x0e\x32\x15.ptsl.SessionRatePull\"\\\n*SetSessionVideoRatePullSettingsRequestBody\x12.\n\x0fvideo_rate_pull\x18\x01 \x01(\x0e\x32\x15.ptsl.SessionRatePull\"\x95\x01\n\x1eSetSessionStartTimeRequestBody\x12\x1a\n\x12session_start_time\x18\x01 \x01(\t\x12\x33\n\x11track_offset_opts\x18\x02 \x01(\x0e\x32\x18.ptsl.TrackOffsetOptions\x12\"\n\x1amaintain_relative_position\x18\x03 \x01(\x08\"5\n\x1bSetSessionLengthRequestBody\x12\x16\n\x0esession_length\x18\x01 \x01(\t\"-\n\x1aGetPTSLVersionResponseBody\x12\x0f\n\x07version\x18\x01 \x01(\x05\"\x80\x01\n\x1bGetPlaybackModeResponseBody\x12/\n\x10\x63urrent_settings\x18\x01 \x03(\x0e\x32\x15.ptsl.PM_PlaybackMode\x12\x30\n\x11possible_settings\x18\x02 \x03(\x0e\x32\x15.ptsl.PM_PlaybackMode\"y\n\x19GetRecordModeResponseBody\x12,\n\x0f\x63urrent_setting\x18\x01 \x01(\x0e\x32\x13.ptsl.RM_RecordMode\x12.\n\x11possible_settings\x18\x02 \x03(\x0e\x32\x13.ptsl.RM_RecordMode\"\x85\x01\n\x1dGetTransportStateResponseBody\x12\x30\n\x0f\x63urrent_setting\x18\x01 \x01(\x0e\x32\x17.ptsl.TS_TransportState\x12\x32\n\x11possible_settings\x18\x02 \x03(\x0e\x32\x17.ptsl.TS_TransportState\";\n\x1dGetTransportArmedResponseBody\x12\x1a\n\x12is_transport_armed\x18\x01 \x01(\x08\"7\n\x1e\x43learMemoryLocationRequestBody\x12\x15\n\rlocation_list\x18\x01 \x03(\x05\"5\n\x1e\x41uthorizeConnectionRequestBody\x12\x13\n\x0b\x61uth_string\x18\x01 \x01(\t\"]\n\x1f\x41uthorizeConnectionResponseBody\x12\x15\n\ris_authorized\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t\"t\n\x1dRenameSelectedClipRequestBody\x12,\n\rclip_location\x18\x01 \x01(\x0e\x32\x15.ptsl.CL_ClipLocation\x12\x10\n\x08new_name\x18\x02 \x01(\t\x12\x13\n\x0brename_file\x18\x03 \x01(\x08\"W\n\x1bRenameTargetClipRequestBody\x12\x11\n\tclip_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\x12\x13\n\x0brename_file\x18\x03 \x01(\x08\"\x83\x02\n\x0eMemoryLocation\x12\x0e\n\x06number\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\t\x12-\n\x0ftime_properties\x18\x05 \x01(\x0e\x32\x14.ptsl.TimeProperties\x12\x30\n\treference\x18\x06 \x01(\x0e\x32\x1d.ptsl.MemoryLocationReference\x12:\n\x12general_properties\x18\x07 \x01(\x0b\x32\x1e.ptsl.MemoryLocationProperties\x12\x10\n\x08\x63omments\x18\x08 \x01(\t\"\xfb\x01\n\x18MemoryLocationProperties\x12\x15\n\rzoom_settings\x18\x01 \x01(\x08\x12\x1b\n\x13pre_post_roll_times\x18\x02 \x01(\x08\x12\x18\n\x10track_visibility\x18\x03 \x01(\x08\x12\x15\n\rtrack_heights\x18\x04 \x01(\x08\x12\x15\n\rgroup_enables\x18\x05 \x01(\x08\x12\x1c\n\x14window_configuration\x18\x06 \x01(\x08\x12\"\n\x1awindow_configuration_index\x18\x07 \x01(\x05\x12!\n\x19window_configuration_name\x18\x08 \x01(\t\"\x92\x02\n\x1d\x45\x64itMemoryLocationRequestBody\x12\x0e\n\x06number\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\t\x12-\n\x0ftime_properties\x18\x05 \x01(\x0e\x32\x14.ptsl.TimeProperties\x12\x30\n\treference\x18\x06 \x01(\x0e\x32\x1d.ptsl.MemoryLocationReference\x12:\n\x12general_properties\x18\x07 \x01(\x0b\x32\x1e.ptsl.MemoryLocationProperties\x12\x10\n\x08\x63omments\x18\x08 \x01(\t\" \n\x1e\x45\x64itMemoryLocationResponseBody\"\x94\x02\n\x1f\x43reateMemoryLocationRequestBody\x12\x0e\n\x06number\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\t\x12-\n\x0ftime_properties\x18\x05 \x01(\x0e\x32\x14.ptsl.TimeProperties\x12\x30\n\treference\x18\x06 \x01(\x0e\x32\x1d.ptsl.MemoryLocationReference\x12:\n\x12general_properties\x18\x07 \x01(\x0b\x32\x1e.ptsl.MemoryLocationProperties\x12\x10\n\x08\x63omments\x18\x08 \x01(\t\"\"\n CreateMemoryLocationResponseBody\"\x1f\n\x1dGetMemoryLocationsRequestBody\"P\n\x1eGetMemoryLocationsResponseBody\x12.\n\x10memory_locations\x18\x01 \x03(\x0b\x32\x14.ptsl.MemoryLocation\"O\n\x1dRegisterConnectionRequestBody\x12\x14\n\x0c\x63ompany_name\x18\x01 \x01(\t\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\"4\n\x1eRegisterConnectionResponseBody\x12\x12\n\nsession_id\x18\x01 \x01(\t*\x8a\r\n\tCommandId\x12\x11\n\rCreateSession\x10\x00\x12\x0f\n\x0bOpenSession\x10\x01\x12\n\n\x06Import\x10\x02\x12\x10\n\x0cGetTrackList\x10\x03\x12\x19\n\x15SelectAllClipsOnTrack\x10\x04\x12!\n\x1d\x45xtendSelectionToTargetTracks\x10\x05\x12\x13\n\x0fTrimToSelection\x10\x06\x12\x1c\n\x18\x43reateFadesBasedOnPreset\x10\x07\x12\x15\n\x11RenameTargetTrack\x10\x08\x12\x13\n\x0f\x43onsolidateClip\x10\t\x12\x16\n\x12\x45xportClipsAsFiles\x10\n\x12 \n\x1c\x45xportSelectedTracksAsAAFOMF\x10\x0b\x12\x11\n\rGetTaskStatus\x10\x0c\x12\x12\n\x0eHostReadyCheck\x10\r\x12\x1b\n\x17RefreshTargetAudioFiles\x10\x0e\x12 \n\x1cRefreshAllModifiedAudioFiles\x10\x0f\x12\x13\n\x0fGetFileLocation\x10\x10\x12\x10\n\x0c\x43loseSession\x10\x11\x12\x0f\n\x0bSaveSession\x10\x12\x12\x11\n\rSaveSessionAs\x10\x13\x12\x07\n\x03\x43ut\x10\x14\x12\x08\n\x04\x43opy\x10\x15\x12\t\n\x05Paste\x10\x16\x12\t\n\x05\x43lear\x10\x17\x12\x0e\n\nCutSpecial\x10\x18\x12\x0f\n\x0b\x43opySpecial\x10\x19\x12\x10\n\x0c\x43learSpecial\x10\x1a\x12\x10\n\x0cPasteSpecial\x10\x1b\x12\r\n\tExportMix\x10\x1c\x12\x08\n\x04Spot\x10\x1d\x12\x1b\n\x17\x45xportSessionInfoAsText\x10\x1e\x12\x18\n\x14GetDynamicProperties\x10\x1f\x12\x13\n\x0fSetPlaybackMode\x10 \x12\x11\n\rSetRecordMode\x10!\x12\x19\n\x15GetSessionAudioFormat\x10\"\x12\x18\n\x14GetSessionSampleRate\x10#\x12\x16\n\x12GetSessionBitDepth\x10$\x12\x1e\n\x1aGetSessionInterleavedState\x10%\x12\x1a\n\x16GetSessionTimeCodeRate\x10&\x12\x1c\n\x18GetSessionFeetFramesRate\x10\'\x12#\n\x1fGetSessionAudioRatePullSettings\x10(\x12#\n\x1fGetSessionVideoRatePullSettings\x10)\x12\x12\n\x0eGetSessionName\x10*\x12\x12\n\x0eGetSessionPath\x10+\x12\x17\n\x13GetSessionStartTime\x10,\x12\x14\n\x10GetSessionLength\x10-\x12\x19\n\x15SetSessionAudioFormat\x10.\x12\x16\n\x12SetSessionBitDepth\x10/\x12\x1e\n\x1aSetSessionInterleavedState\x10\x30\x12\x1a\n\x16SetSessionTimeCodeRate\x10\x31\x12\x1c\n\x18SetSessionFeetFramesRate\x10\x32\x12#\n\x1fSetSessionAudioRatePullSettings\x10\x33\x12#\n\x1fSetSessionVideoRatePullSettings\x10\x34\x12\x17\n\x13SetSessionStartTime\x10\x35\x12\x14\n\x10SetSessionLength\x10\x36\x12\x12\n\x0eGetPTSLVersion\x10\x37\x12\x13\n\x0fGetPlaybackMode\x10\x38\x12\x11\n\rGetRecordMode\x10\x39\x12\x15\n\x11GetTransportArmed\x10:\x12\x15\n\x11GetTransportState\x10;\x12\x17\n\x13\x41uthorizeConnection\x10<\x12\x17\n\x13\x43learMemoryLocation\x10=\x12\x16\n\x12RenameSelectedClip\x10>\x12\x14\n\x10RenameTargetClip\x10?\x12\x13\n\x0fTogglePlayState\x10@\x12\x16\n\x12ToggleRecordEnable\x10\x41\x12\x11\n\rPlayHalfSpeed\x10\x42\x12\x13\n\x0fRecordHalfSpeed\x10\x43\x12\x16\n\x12\x45\x64itMemoryLocation\x10\x44\x12\x16\n\x12GetMemoryLocations\x10\x45\x12\x16\n\x12RegisterConnection\x10\x46\x12\x18\n\x14\x43reateMemoryLocation\x10G*\xa7\x01\n\nTaskStatus\x12\n\n\x06Queued\x10\x00\x12\x0b\n\x07Pending\x10\x01\x12\x0e\n\nInProgress\x10\x02\x12\r\n\tCompleted\x10\x03\x12\n\n\x06\x46\x61iled\x10\x04\x12\x17\n\x13WaitingForUserInput\x10\x05\x12\x1c\n\x18\x43ompletedWithBadResponse\x10\x06\x12\x1e\n\x1a\x46\x61iledWithBadErrorResponse\x10\x07*\xed\x07\n\x10\x43ommandErrorType\x12\x17\n\x13OS_WritePermissions\x10\x00\x12\x10\n\x0cOS_ErrorCode\x10\x01\x12\x16\n\x12OS_NoLocationFound\x10\x02\x12\x15\n\x11OS_NoSessionFound\x10\x03\x12\x17\n\x13OS_FilePathLocation\x10\x04\x12\x10\n\x0cOS_ReadError\x10\x05\x12\x10\n\x0cOS_DiskSpace\x10\x06\x12\x14\n\x10OS_DuplicateName\x10\x07\x12\x18\n\x14OS_IllegalCharacters\x10\x08\x12\x16\n\x12OS_CharactersLimit\x10\t\x12\x1d\n\x19OS_ProToolsIsNotAvailable\x10\n\x12\x16\n\x12OS_NoFilePathFound\x10\x0b\x12\x13\n\x0fPT_UnknownError\x10\x64\x12\x16\n\x12PT_NoTemplateGroup\x10\x65\x12\x11\n\rPT_NoTemplate\x10\x66\x12\x19\n\x15PT_SampleRateMismatch\x10g\x12\x18\n\x14PT_NoVideoTrackFound\x10h\x12\x14\n\x10PT_NoTracksFound\x10i\x12\x16\n\x12PT_NoOpenedSession\x10j\x12\x13\n\x0fPT_NoTrackFound\x10k\x12\x13\n\x0fPT_NoClipsFound\x10l\x12\x12\n\x0ePT_NoSelection\x10m\x12\x12\n\x0ePT_RecordDrive\x10n\x12\x14\n\x10PT_NoPresetFound\x10o\x12\x12\n\x0ePT_FileTypeMXF\x10p\x12\x15\n\x11PT_CopyOptionCopy\x10q\x12\x15\n\x11PT_CopyOptionLink\x10r\x12\x14\n\x10PT_QuantizeEdits\x10s\x12\x1b\n\x17PT_ExportAsMultichannel\x10t\x12 \n\x1cPT_IllegalCharactersComments\x10u\x12$\n PT_IllegalCharactersSequenceName\x10v\x12\x1c\n\x18PT_MaxCharactersComments\x10w\x12 \n\x1cPT_MaxCharactersSequenceName\x10x\x12\x15\n\x11PT_NoSequenceName\x10y\x12\x12\n\x0ePT_InvalidTask\x10z\x12\x13\n\x0fPT_FileNotFound\x10{\x12\x17\n\x13PT_InvalidSelection\x10|\x12\x16\n\x12PT_ReadOnlySession\x10}\x12\x17\n\x13PT_InvalidParameter\x10~\x12\x18\n\x13SDK_VersionMismatch\x10\x91\x03\x12\x17\n\x12SDK_NotImplemented\x10\x92\x03*\xf3\x01\n\tTrackType\x12\x0b\n\x07Unknown\x10\x00\x12\x08\n\x04Midi\x10\x01\x12\x0e\n\nAudioTrack\x10\x02\x12\x07\n\x03\x41ux\x10\x03\x12\x0e\n\nVideoTrack\x10\x04\x12\x07\n\x03Vca\x10\x05\x12\t\n\x05Tempo\x10\x06\x12\x0b\n\x07Markers\x10\x07\x12\t\n\x05Meter\x10\x08\x12\x10\n\x0cKeySignature\x10\t\x12\x10\n\x0c\x43hordSymbols\x10\n\x12\x0e\n\nInstrument\x10\x0b\x12\n\n\x06Master\x10\x0c\x12\x08\n\x04Heat\x10\r\x12\x0f\n\x0b\x42\x61sicFolder\x10\x0e\x12\x11\n\rRoutingFolder\x10\x0f\x12\x0c\n\x08\x43ompLane\x10\x10*e\n\x13TrackAttributeState\x12\x08\n\x04None\x10\x00\x12\x11\n\rSetExplicitly\x10\x01\x12\x11\n\rSetImplicitly\x10\x02\x12\x1e\n\x1aSetExplicitlyAndImplicitly\x10\x03*<\n\x08\x46ileType\x12\x0b\n\x07\x46T_WAVE\x10\x00\x12\x0b\n\x07\x46T_AIFF\x10\x01\x12\n\n\x06\x46T_AAF\x10\x02\x12\n\n\x06\x46T_OMF\x10\x03*\x82\x01\n\nIOSettings\x12\x0b\n\x07IO_None\x10\x00\x12\x0b\n\x07IO_Last\x10\x01\x12\x10\n\x0cIO_StereoMix\x10\x02\x12\x10\n\x0cIO_51FilmMix\x10\x03\x12\x11\n\rIO_51SMPTEMix\x10\x04\x12\x0f\n\x0bIO_51DTSMix\x10\x05\x12\x12\n\x0eIO_UserDefined\x10\x06*I\n\nImportType\x12\x0b\n\x07Session\x10\x00\x12\t\n\x05\x41udio\x10\x01\x12\t\n\x05Video\x10\x02\x12\x08\n\x04MIDI\x10\x03\x12\x0e\n\nClipGroups\x10\x04*\x83\x01\n\x11\x41udioMediaOptions\x12\x15\n\x11LinkToSourceAudio\x10\x00\x12\x17\n\x13\x43opyFromSourceAudio\x10\x01\x12\x1e\n\x1a\x43onsolidateFromSourceAudio\x10\x02\x12\x1e\n\x1a\x46orceToTargetSessionFormat\x10\x03*f\n\x11VideoMediaOptions\x12\x15\n\x11LinkToSourceVideo\x10\x00\x12\x17\n\x13\x43opyFromSourceVideo\x10\x01\x12!\n\x1dImportAsOfflineSatelliteMedia\x10\x02*M\n\x11MatchTrackOptions\x12\x0b\n\x07MT_None\x10\x00\x12\x12\n\x0eMT_MatchTracks\x10\x01\x12\x17\n\x13MT_ImportAsNewTrack\x10\x02*x\n\x16TimeCodeMappingOptions\x12\"\n\x1eMaintainAbsoluteTimeCodeValues\x10\x00\x12\"\n\x1eMaintainRelativeTimeCodeValues\x10\x01\x12\x16\n\x12MapStartTimeCodeTo\x10\x02*[\n\x12TrackOffsetOptions\x12\r\n\tBarsBeats\x10\x00\x12\x0b\n\x07MinSecs\x10\x01\x12\x0c\n\x08TimeCode\x10\x02\x12\x0e\n\nFeetFrames\x10\x03\x12\x0b\n\x07Samples\x10\x04*K\n\x11\x43onversionQuality\x12\x07\n\x03Low\x10\x00\x12\x08\n\x04Good\x10\x01\x12\n\n\x06\x42\x65tter\x10\x02\x12\x08\n\x04\x42\x65st\x10\x03\x12\r\n\tTweakHead\x10\x04*s\n\x13MainPlaylistOptions\x12\"\n\x1eImportReplaceExistingPlaylists\x10\x00\x12\'\n#ImportOverlayNewOnExistingPlaylists\x10\x01\x12\x0f\n\x0b\x44oNotImport\x10\x02*M\n\x0f\x41udioOperations\x12\x0c\n\x08\x41\x64\x64\x41udio\x10\x00\x12\r\n\tCopyAudio\x10\x01\x12\x10\n\x0c\x43onvertAudio\x10\x02\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x03*X\n\x10MediaDestination\x12\x0b\n\x07MD_None\x10\x00\x12\x15\n\x11MD_MainVideoTrack\x10\x01\x12\x0f\n\x0bMD_NewTrack\x10\x02\x12\x0f\n\x0bMD_ClipList\x10\x03*b\n\rMediaLocation\x12\x0b\n\x07ML_None\x10\x00\x12\x13\n\x0fML_SessionStart\x10\x01\x12\x10\n\x0cML_SongStart\x10\x02\x12\x10\n\x0cML_Selection\x10\x03\x12\x0b\n\x07ML_Spot\x10\x04*\xc6\x02\n\x0fTrackListFilter\x12\x07\n\x03\x41ll\x10\x00\x12\x0c\n\x08Selected\x10\x01\x12\x16\n\x12SelectedExplicitly\x10\x02\x12\x16\n\x12SelectedImplicitly\x10\x03\x12\x1b\n\x17WithClipsOnMainPlaylist\x10\x04\x12 \n\x1cWithAutomationOnMainPlaylist\x10\x05\x12\x0c\n\x08Inactive\x10\x06\x12\x16\n\x12InactiveExplicitly\x10\x07\x12\x16\n\x12InactiveImplicitly\x10\x08\x12\n\n\x06Hidden\x10\t\x12\x14\n\x10HiddenExplicitly\x10\n\x12\x14\n\x10HiddenImplicitly\x10\x0b\x12\n\n\x06Locked\x10\x0c\x12\t\n\x05Muted\x10\r\x12\n\n\x06\x46rozen\x10\x0e\x12\x08\n\x04Open\x10\x0f\x12\n\n\x06Online\x10\x10*5\n\x10SpotLocationType\x12\t\n\x05Start\x10\x00\x12\r\n\tSyncPoint\x10\x01\x12\x07\n\x03\x45nd\x10\x02*Q\n\x0c\x45xportFormat\x12\x0b\n\x07\x45\x46_None\x10\x00\x12\x0b\n\x07\x45\x46_Mono\x10\x01\x12\x13\n\x0f\x45\x46_MultipleMono\x10\x02\x12\x12\n\x0e\x45\x46_Interleaved\x10\x03*D\n\x0e\x45xportFileType\x12\x07\n\x03WAV\x10\x00\x12\x08\n\x04\x41IFF\x10\x01\x12\x07\n\x03MXF\x10\x02\x12\x07\n\x03MP3\x10\x03\x12\r\n\tQuickTime\x10\x04*>\n\x08\x42itDepth\x12\x0c\n\x08\x42it_None\x10\x00\x12\t\n\x05\x42it16\x10\x01\x12\t\n\x05\x42it24\x10\x02\x12\x0e\n\nBit32Float\x10\x03*F\n\x17ResolveDuplicateNamesBy\x12\x10\n\x0c\x41utoRenaming\x10\x00\x12\x19\n\x15ReplacingWithNewFiles\x10\x01*O\n\x13\x45xportAsAAFFileType\x12\x0b\n\x07\x41\x41\x46_WAV\x10\x00\x12\x0c\n\x08\x41\x41\x46_AIFF\x10\x01\x12\x0b\n\x07\x41\x41\x46_MXF\x10\x02\x12\x10\n\x0c\x41\x41\x46_Embedded\x10\x03*/\n\x0f\x41\x41\x46\x46ileBitDepth\x12\r\n\tAAF_Bit16\x10\x00\x12\r\n\tAAF_Bit24\x10\x01*^\n\nCopyOption\x12\x1e\n\x1a\x43onsolidateFromSourceMedia\x10\x00\x12\x17\n\x13\x43opyFromSourceMedia\x10\x01\x12\x17\n\x13LinkFromSourceMedia\x10\x02*\xe8\x01\n\x16\x46ileLocationTypeFilter\x12\r\n\tAll_Files\x10\x00\x12\x14\n\x10OnTimeline_Files\x10\x01\x12\x17\n\x13NotOnTimeline_Files\x10\x02\x12\x10\n\x0cOnline_Files\x10\x03\x12\x11\n\rOffline_Files\x10\x04\x12\x0f\n\x0b\x41udio_Files\x10\x05\x12\x0f\n\x0bVideo_Files\x10\x06\x12\x12\n\x0eRendered_Files\x10\x07\x12\x19\n\x15SelectedClipsTimeline\x10\x65\x12\x1a\n\x16SelectedClipsClipsList\x10\x66*w\n\x15\x41utomationDataOptions\x12\x12\n\x0e\x41ll_Automation\x10\x00\x12\x12\n\x0ePan_Automation\x10\x01\x12\x15\n\x11PlugIn_Automation\x10\x02\x12\r\n\tClip_Gain\x10\x03\x12\x10\n\x0c\x43lip_Effects\x10\x04*^\n\x13PasteSpecialOptions\x12\t\n\x05Merge\x10\x00\x12\x1c\n\x18Repeat_To_Fill_Selection\x10\x01\x12\x1e\n\x1aTo_Current_Automation_Type\x10\x02*4\n\nTripleBool\x12\x0b\n\x07TB_None\x10\x00\x12\x0c\n\x08TB_False\x10\x01\x12\x0b\n\x07TB_True\x10\x02*5\n\rEM_SourceType\x12\x0f\n\x0bPhysicalOut\x10\x00\x12\x07\n\x03\x42us\x10\x01\x12\n\n\x06Output\x10\x02**\n\x0f\x43ompressionType\x12\x0b\n\x07\x43T_None\x10\x00\x12\n\n\x06\x43T_PCM\x10\x01*o\n\nSampleRate\x12\x0b\n\x07SR_None\x10\x00\x12\x0c\n\x08SR_44100\x10\x01\x12\x0c\n\x08SR_48000\x10\x02\x12\x0c\n\x08SR_96000\x10\x03\x12\r\n\tSR_176400\x10\x04\x12\r\n\tSR_192000\x10\x05\x12\x0c\n\x08SR_88200\x10\x06*K\n\x15\x45M_VideoExportOptions\x12\x0b\n\x07VE_None\x10\x00\x12\x13\n\x0fVE_SameAsSource\x10\x01\x12\x10\n\x0cVE_Transcode\x10\x02*l\n\x0b\x45M_FileType\x12\x0b\n\x07\x45M_None\x10\x00\x12\n\n\x06\x45M_MOV\x10\x01\x12\n\n\x06\x45M_WAV\x10\x02\x12\x0b\n\x07\x45M_AIFF\x10\x03\x12\n\n\x06\x45M_MP3\x10\x04\x12\x10\n\x0c\x45M_MXFOPAtom\x10\x05\x12\r\n\tEM_WAVADM\x10\x06*R\n\x12\x45M_FileDestination\x12\x0e\n\nEM_FD_None\x10\x00\x12\x17\n\x13\x45M_FD_SessionFolder\x10\x01\x12\x13\n\x0f\x45M_FD_Directory\x10\x02*U\n\x11\x45M_DeliveryFormat\x12\x0e\n\nEM_DF_None\x10\x00\x12\x1a\n\x16\x45M_DF_FilePerMixSource\x10\x01\x12\x14\n\x10\x45M_DF_SingleFile\x10\x02*\xbf\x02\n\rDP_ValueTypes\x12\x10\n\x0c\x44P_VT_double\x10\x00\x12\x0f\n\x0b\x44P_VT_float\x10\x01\x12\x0f\n\x0b\x44P_VT_int32\x10\x02\x12\x0f\n\x0b\x44P_VT_int64\x10\x03\x12\x10\n\x0c\x44P_VT_uint32\x10\x04\x12\x10\n\x0c\x44P_VT_uint64\x10\x05\x12\x10\n\x0c\x44P_VT_sint32\x10\x06\x12\x10\n\x0c\x44P_VT_sint64\x10\x07\x12\x11\n\rDP_VT_fixed32\x10\x08\x12\x11\n\rDP_VT_fixed64\x10\t\x12\x12\n\x0e\x44P_VT_sfixed32\x10\n\x12\x12\n\x0e\x44P_VT_sfixed64\x10\x0b\x12\x0e\n\nDP_VT_bool\x10\x0c\x12\x10\n\x0c\x44P_VT_string\x10\r\x12\x0f\n\x0b\x44P_VT_bytes\x10\x0e\x12\x0e\n\nDP_VT_enum\x10\x0f\x12\x10\n\x0c\x44P_VT_object\x10\x10*D\n\x13\x44ynamicPropertyType\x12\x13\n\x0f\x44P_EM_CodecInfo\x10\x00\x12\x18\n\x14\x44P_EM_DolbyAtmosInfo\x10\x01*6\n\rTrackListType\x12\r\n\tAllTracks\x10\x00\x12\x16\n\x12SelectedTracksOnly\x10\x01*Z\n\x10\x46\x61\x64\x65HandlingType\x12\x12\n\x0eShowCrossfades\x10\x00\x12\x16\n\x12\x44ontShowCrossfades\x10\x01\x12\x1a\n\x16\x43ombineCrossfadedClips\x10\x02**\n\x10TextAsFileFormat\x12\x0c\n\x08TextEdit\x10\x00\x12\x08\n\x04UTF8\x10\x01*.\n\x0e\x45SI_OutputType\x12\x0c\n\x08\x45SI_File\x10\x00\x12\x0e\n\nESI_String\x10\x01*F\n\x0fPM_PlaybackMode\x12\r\n\tPM_Normal\x10\x00\x12\x0b\n\x07PM_Loop\x10\x01\x12\x17\n\x13PM_DynamicTransport\x10\x02*~\n\rRM_RecordMode\x12\r\n\tRM_Normal\x10\x00\x12\x0b\n\x07RM_Loop\x10\x01\x12\x12\n\x0eRM_Destructive\x10\x02\x12\x11\n\rRM_QuickPunch\x10\x03\x12\x11\n\rRM_TrackPunch\x10\x04\x12\x17\n\x13RM_DestructivePunch\x10\x05*0\n\x12SessionAudioFormat\x12\x0c\n\x08SAF_WAVE\x10\x00\x12\x0c\n\x08SAF_AIFF\x10\x01*\xf4\x02\n\x13SessionTimeCodeRate\x12\x11\n\rSTCR_Fps23976\x10\x00\x12\x0e\n\nSTCR_Fps24\x10\x01\x12\x0e\n\nSTCR_Fps25\x10\x02\x12\x10\n\x0cSTCR_Fps2997\x10\x03\x12\x14\n\x10STCR_Fps2997Drop\x10\x04\x12\x0e\n\nSTCR_Fps30\x10\x05\x12\x12\n\x0eSTCR_Fps30Drop\x10\x06\x12\x11\n\rSTCR_Fps47952\x10\x07\x12\x0e\n\nSTCR_Fps48\x10\x08\x12\x0e\n\nSTCR_Fps50\x10\t\x12\x10\n\x0cSTCR_Fps5994\x10\n\x12\x14\n\x10STCR_Fps5994Drop\x10\x0b\x12\x0e\n\nSTCR_Fps60\x10\x0c\x12\x12\n\x0eSTCR_Fps60Drop\x10\r\x12\x0f\n\x0bSTCR_Fps100\x10\x0e\x12\x11\n\rSTCR_Fps11988\x10\x0f\x12\x15\n\x11STCR_Fps11988Drop\x10\x10\x12\x0f\n\x0bSTCR_Fps120\x10\x11\x12\x13\n\x0fSTCR_Fps120Drop\x10\x12*J\n\x15SessionFeetFramesRate\x12\x11\n\rSFFR_Fps23976\x10\x00\x12\x0e\n\nSFFR_Fps24\x10\x01\x12\x0e\n\nSFFR_Fps25\x10\x02*\xa5\x01\n\x0fSessionRatePull\x12\x0c\n\x08SRP_None\x10\x00\x12\x0c\n\x08SRP_Up01\x10\x01\x12\x0e\n\nSRP_Down01\x10\x02\x12\x0b\n\x07SRP_Up4\x10\x03\x12\x0f\n\x0bSRP_Up4Up01\x10\x04\x12\x11\n\rSRP_Up4Down01\x10\x05\x12\r\n\tSRP_Down4\x10\x06\x12\x11\n\rSRP_Down4Up01\x10\x07\x12\x13\n\x0fSRP_Down4Down01\x10\x08*\xb1\x03\n\x11TS_TransportState\x12\x17\n\x13TS_TransportPlaying\x10\x00\x12\x17\n\x13TS_TransportStopped\x10\x01\x12\x19\n\x15TS_TransportRecording\x10\x02\x12 \n\x1cTS_TransportPlayingHalfSpeed\x10\x03\x12\"\n\x1eTS_TransportRecordingHalfSpeed\x10\x04\x12\x1b\n\x17TS_TransportFastForward\x10\x05\x12\x16\n\x12TS_TransportRewind\x10\x06\x12\x15\n\x11TS_TransportScrub\x10\x07\x12\x17\n\x13TS_TransportShuttle\x10\x08\x12\x16\n\x12TS_TransportPrimed\x10\t\x12\x18\n\x14TS_TransportIsCueing\x10\n\x12\x16\n\x12TS_TransportIsCued\x10\x0b\x12 \n\x1cTS_TransportIsCuedForPreview\x10\x0c\x12\x1a\n\x16TS_TransportIsStopping\x10\r\x12\x1c\n\x18TS_TransportIsPreviewing\x10\x0e*4\n\x0f\x43L_ClipLocation\x12\x10\n\x0c\x43L_ClipsList\x10\x00\x12\x0f\n\x0b\x43L_Timeline\x10\x01*>\n\x0eTimeProperties\x12\r\n\tTP_Marker\x10\x00\x12\x10\n\x0cTP_Selection\x10\x01\x12\x0b\n\x07TP_None\x10\x02*<\n\x17MemoryLocationReference\x12\x0f\n\x0bMLR_BarBeat\x10\x00\x12\x10\n\x0cMLR_Absolute\x10\x01\x32u\n\x04PTSL\x12\x30\n\x0fSendGrpcRequest\x12\r.ptsl.Request\x1a\x0e.ptsl.Response\x12;\n\x18SendGrpcStreamingRequest\x12\r.ptsl.Request\x1a\x0e.ptsl.Response0\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PTSL_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMANDID._serialized_start=13695
  _COMMANDID._serialized_end=15369
  _TASKSTATUS._serialized_start=15372
  _TASKSTATUS._serialized_end=15539
  _COMMANDERRORTYPE._serialized_start=15542
  _COMMANDERRORTYPE._serialized_end=16547
  _TRACKTYPE._serialized_start=16550
  _TRACKTYPE._serialized_end=16793
  _TRACKATTRIBUTESTATE._serialized_start=16795
  _TRACKATTRIBUTESTATE._serialized_end=16896
  _FILETYPE._serialized_start=16898
  _FILETYPE._serialized_end=16958
  _IOSETTINGS._serialized_start=16961
  _IOSETTINGS._serialized_end=17091
  _IMPORTTYPE._serialized_start=17093
  _IMPORTTYPE._serialized_end=17166
  _AUDIOMEDIAOPTIONS._serialized_start=17169
  _AUDIOMEDIAOPTIONS._serialized_end=17300
  _VIDEOMEDIAOPTIONS._serialized_start=17302
  _VIDEOMEDIAOPTIONS._serialized_end=17404
  _MATCHTRACKOPTIONS._serialized_start=17406
  _MATCHTRACKOPTIONS._serialized_end=17483
  _TIMECODEMAPPINGOPTIONS._serialized_start=17485
  _TIMECODEMAPPINGOPTIONS._serialized_end=17605
  _TRACKOFFSETOPTIONS._serialized_start=17607
  _TRACKOFFSETOPTIONS._serialized_end=17698
  _CONVERSIONQUALITY._serialized_start=17700
  _CONVERSIONQUALITY._serialized_end=17775
  _MAINPLAYLISTOPTIONS._serialized_start=17777
  _MAINPLAYLISTOPTIONS._serialized_end=17892
  _AUDIOOPERATIONS._serialized_start=17894
  _AUDIOOPERATIONS._serialized_end=17971
  _MEDIADESTINATION._serialized_start=17973
  _MEDIADESTINATION._serialized_end=18061
  _MEDIALOCATION._serialized_start=18063
  _MEDIALOCATION._serialized_end=18161
  _TRACKLISTFILTER._serialized_start=18164
  _TRACKLISTFILTER._serialized_end=18490
  _SPOTLOCATIONTYPE._serialized_start=18492
  _SPOTLOCATIONTYPE._serialized_end=18545
  _EXPORTFORMAT._serialized_start=18547
  _EXPORTFORMAT._serialized_end=18628
  _EXPORTFILETYPE._serialized_start=18630
  _EXPORTFILETYPE._serialized_end=18698
  _BITDEPTH._serialized_start=18700
  _BITDEPTH._serialized_end=18762
  _RESOLVEDUPLICATENAMESBY._serialized_start=18764
  _RESOLVEDUPLICATENAMESBY._serialized_end=18834
  _EXPORTASAAFFILETYPE._serialized_start=18836
  _EXPORTASAAFFILETYPE._serialized_end=18915
  _AAFFILEBITDEPTH._serialized_start=18917
  _AAFFILEBITDEPTH._serialized_end=18964
  _COPYOPTION._serialized_start=18966
  _COPYOPTION._serialized_end=19060
  _FILELOCATIONTYPEFILTER._serialized_start=19063
  _FILELOCATIONTYPEFILTER._serialized_end=19295
  _AUTOMATIONDATAOPTIONS._serialized_start=19297
  _AUTOMATIONDATAOPTIONS._serialized_end=19416
  _PASTESPECIALOPTIONS._serialized_start=19418
  _PASTESPECIALOPTIONS._serialized_end=19512
  _TRIPLEBOOL._serialized_start=19514
  _TRIPLEBOOL._serialized_end=19566
  _EM_SOURCETYPE._serialized_start=19568
  _EM_SOURCETYPE._serialized_end=19621
  _COMPRESSIONTYPE._serialized_start=19623
  _COMPRESSIONTYPE._serialized_end=19665
  _SAMPLERATE._serialized_start=19667
  _SAMPLERATE._serialized_end=19778
  _EM_VIDEOEXPORTOPTIONS._serialized_start=19780
  _EM_VIDEOEXPORTOPTIONS._serialized_end=19855
  _EM_FILETYPE._serialized_start=19857
  _EM_FILETYPE._serialized_end=19965
  _EM_FILEDESTINATION._serialized_start=19967
  _EM_FILEDESTINATION._serialized_end=20049
  _EM_DELIVERYFORMAT._serialized_start=20051
  _EM_DELIVERYFORMAT._serialized_end=20136
  _DP_VALUETYPES._serialized_start=20139
  _DP_VALUETYPES._serialized_end=20458
  _DYNAMICPROPERTYTYPE._serialized_start=20460
  _DYNAMICPROPERTYTYPE._serialized_end=20528
  _TRACKLISTTYPE._serialized_start=20530
  _TRACKLISTTYPE._serialized_end=20584
  _FADEHANDLINGTYPE._serialized_start=20586
  _FADEHANDLINGTYPE._serialized_end=20676
  _TEXTASFILEFORMAT._serialized_start=20678
  _TEXTASFILEFORMAT._serialized_end=20720
  _ESI_OUTPUTTYPE._serialized_start=20722
  _ESI_OUTPUTTYPE._serialized_end=20768
  _PM_PLAYBACKMODE._serialized_start=20770
  _PM_PLAYBACKMODE._serialized_end=20840
  _RM_RECORDMODE._serialized_start=20842
  _RM_RECORDMODE._serialized_end=20968
  _SESSIONAUDIOFORMAT._serialized_start=20970
  _SESSIONAUDIOFORMAT._serialized_end=21018
  _SESSIONTIMECODERATE._serialized_start=21021
  _SESSIONTIMECODERATE._serialized_end=21393
  _SESSIONFEETFRAMESRATE._serialized_start=21395
  _SESSIONFEETFRAMESRATE._serialized_end=21469
  _SESSIONRATEPULL._serialized_start=21472
  _SESSIONRATEPULL._serialized_end=21637
  _TS_TRANSPORTSTATE._serialized_start=21640
  _TS_TRANSPORTSTATE._serialized_end=22073
  _CL_CLIPLOCATION._serialized_start=22075
  _CL_CLIPLOCATION._serialized_end=22127
  _TIMEPROPERTIES._serialized_start=22129
  _TIMEPROPERTIES._serialized_end=22191
  _MEMORYLOCATIONREFERENCE._serialized_start=22193
  _MEMORYLOCATIONREFERENCE._serialized_end=22253
  _EMPTYMESSAGE._serialized_start=20
  _EMPTYMESSAGE._serialized_end=34
  _COMMANDERROR._serialized_start=36
  _COMMANDERROR._serialized_end=153
  _REQUESTHEADER._serialized_start=155
  _REQUESTHEADER._serialized_end=258
  _REQUEST._serialized_start=260
  _REQUEST._serialized_end=333
  _RESPONSEHEADER._serialized_start=335
  _RESPONSEHEADER._serialized_end=454
  _RESPONSE._serialized_start=456
  _RESPONSE._serialized_end=561
  _PAGINATION._serialized_start=563
  _PAGINATION._serialized_end=621
  _TRACKATTRIBUTES._serialized_start=624
  _TRACKATTRIBUTES._serialized_end=1058
  _TRACK._serialized_start=1061
  _TRACK._serialized_end=1227
  _GETTASKSTATUSREQUESTBODY._serialized_start=1229
  _GETTASKSTATUSREQUESTBODY._serialized_end=1272
  _GETTASKSTATUSRESPONSEBODY._serialized_start=1274
  _GETTASKSTATUSRESPONSEBODY._serialized_end=1370
  _CREATESESSIONREQUESTBODY._serialized_start=1373
  _CREATESESSIONREQUESTBODY._serialized_end=1778
  _OPENSESSIONREQUESTBODY._serialized_start=1780
  _OPENSESSIONREQUESTBODY._serialized_end=1826
  _TRACKDATATOIMPORT._serialized_start=1828
  _TRACKDATATOIMPORT._serialized_end=1950
  _SESSIONDATAIMPORT._serialized_start=1953
  _SESSIONDATAIMPORT._serialized_end=2151
  _SESSIONDATA._serialized_start=2154
  _SESSIONDATA._serialized_end=2596
  _SPOTLOCATIONDATA._serialized_start=2599
  _SPOTLOCATIONDATA._serialized_end=2740
  _AUDIODATA._serialized_start=2743
  _AUDIODATA._serialized_end=2979
  _VIDEODATA._serialized_start=2981
  _VIDEODATA._serialized_end=2992
  _MIDIDATA._serialized_start=2994
  _MIDIDATA._serialized_end=3004
  _CLIPGROUPSDATA._serialized_start=3006
  _CLIPGROUPSDATA._serialized_end=3022
  _IMPORTREQUESTBODY._serialized_start=3025
  _IMPORTREQUESTBODY._serialized_end=3183
  _IMPORTRESPONSEBODY._serialized_start=3185
  _IMPORTRESPONSEBODY._serialized_end=3299
  _TRACKLISTINVERTIBLEFILTER._serialized_start=3301
  _TRACKLISTINVERTIBLEFILTER._serialized_end=3388
  _GETTRACKLISTREQUESTBODY._serialized_start=3391
  _GETTRACKLISTREQUESTBODY._serialized_end=3529
  _GETTRACKLISTRESPONSEBODY._serialized_start=3531
  _GETTRACKLISTRESPONSEBODY._serialized_end=3623
  _SELECTALLCLIPSONTRACKREQUESTBODY._serialized_start=3625
  _SELECTALLCLIPSONTRACKREQUESTBODY._serialized_end=3679
  _SELECTALLCLIPSONTRACKRESPONSEBODY._serialized_start=3681
  _SELECTALLCLIPSONTRACKRESPONSEBODY._serialized_end=3736
  _EXTENDSELECTIONTOTARGETTRACKSREQUESTBODY._serialized_start=3738
  _EXTENDSELECTIONTOTARGETTRACKSREQUESTBODY._serialized_end=3809
  _EXTENDSELECTIONTOTARGETTRACKSRESPONSEBODY._serialized_start=3811
  _EXTENDSELECTIONTOTARGETTRACKSRESPONSEBODY._serialized_end=3883
  _CREATEFADESBASEDONPRESETREQUESTBODY._serialized_start=3885
  _CREATEFADESBASEDONPRESETREQUESTBODY._serialized_end=3976
  _CREATEFADESBASEDONPRESETRESPONSEBODY._serialized_start=3978
  _CREATEFADESBASEDONPRESETRESPONSEBODY._serialized_end=4042
  _RENAMETARGETTRACKREQUESTBODY._serialized_start=4044
  _RENAMETARGETTRACKREQUESTBODY._serialized_end=4132
  _EXPORTCLIPSASFILESREQUESTBODY._serialized_start=4135
  _EXPORTCLIPSASFILESREQUESTBODY._serialized_end=4389
  _EXPORTSELECTEDTRACKSASAAFOMFREQUESTBODY._serialized_start=4392
  _EXPORTSELECTEDTRACKSASAAFOMFREQUESTBODY._serialized_end=4821
  _REFRESHTARGETAUDIOFILESREQUESTBODY._serialized_start=4823
  _REFRESHTARGETAUDIOFILESREQUESTBODY._serialized_end=4878
  _REFRESHTARGETAUDIOFILESRESPONSEBODY._serialized_start=4880
  _REFRESHTARGETAUDIOFILESRESPONSEBODY._serialized_end=4985
  _FILELOCATIONINFO._serialized_start=4987
  _FILELOCATIONINFO._serialized_end=5024
  _FILELOCATION._serialized_start=5026
  _FILELOCATION._serialized_end=5092
  _GETFILELOCATIONREQUESTBODY._serialized_start=5094
  _GETFILELOCATIONREQUESTBODY._serialized_end=5194
  _GETFILELOCATIONRESPONSEBODY._serialized_start=5196
  _GETFILELOCATIONRESPONSEBODY._serialized_end=5302
  _CLOSESESSIONREQUESTBODY._serialized_start=5304
  _CLOSESESSIONREQUESTBODY._serialized_end=5352
  _SAVESESSIONASREQUESTBODY._serialized_start=5354
  _SAVESESSIONASREQUESTBODY._serialized_end=5428
  _CUTSPECIALREQUESTBODY._serialized_start=5430
  _CUTSPECIALREQUESTBODY._serialized_end=5514
  _COPYSPECIALREQUESTBODY._serialized_start=5516
  _COPYSPECIALREQUESTBODY._serialized_end=5601
  _CLEARSPECIALREQUESTBODY._serialized_start=5603
  _CLEARSPECIALREQUESTBODY._serialized_end=5689
  _PASTESPECIALREQUESTBODY._serialized_start=5691
  _PASTESPECIALREQUESTBODY._serialized_end=5773
  _EM_SOURCEINFO._serialized_start=5775
  _EM_SOURCEINFO._serialized_end=5846
  _EM_AUDIOINFO._serialized_start=5849
  _EM_AUDIOINFO._serialized_end=6128
  _PROPERTYCONTAINER._serialized_start=6130
  _PROPERTYCONTAINER._serialized_end=6223
  _EM_CODECINFO._serialized_start=6225
  _EM_CODECINFO._serialized_end=6307
  _EM_VIDEOINFO._serialized_start=6310
  _EM_VIDEOINFO._serialized_end=6507
  _EM_IMPORTOPTIONS._serialized_start=6510
  _EM_IMPORTOPTIONS._serialized_end=6881
  _EM_LOCATIONINFO._serialized_start=6884
  _EM_LOCATIONINFO._serialized_end=7067
  _EM_DOLBYATMOSINFO._serialized_start=7070
  _EM_DOLBYATMOSINFO._serialized_end=7234
  _EXPORTMIXREQUESTBODY._serialized_start=7237
  _EXPORTMIXREQUESTBODY._serialized_end=7643
  _PROPERTYDESCRIPTOR._serialized_start=7646
  _PROPERTYDESCRIPTOR._serialized_end=7859
  _GETDYNAMICPROPERTIESREQUESTBODY._serialized_start=7861
  _GETDYNAMICPROPERTIESREQUESTBODY._serialized_end=7944
  _GETDYNAMICPROPERTIESGROUP._serialized_start=7946
  _GETDYNAMICPROPERTIESGROUP._serialized_end=8065
  _GETDYNAMICPROPERTIESRESPONSEBODY._serialized_start=8068
  _GETDYNAMICPROPERTIESRESPONSEBODY._serialized_end=8205
  _SPOTREQUESTBODY._serialized_start=8207
  _SPOTREQUESTBODY._serialized_end=8327
  _EXPORTSESSIONINFOASTEXTREQUESTBODY._serialized_start=8330
  _EXPORTSESSIONINFOASTEXTREQUESTBODY._serialized_end=8831
  _EXPORTSESSIONINFOASTEXTRESPONSEBODY._serialized_start=8833
  _EXPORTSESSIONINFOASTEXTRESPONSEBODY._serialized_end=8892
  _SETPLAYBACKMODEREQUESTBODY._serialized_start=8894
  _SETPLAYBACKMODEREQUESTBODY._serialized_end=8968
  _SETPLAYBACKMODERESPONSEBODY._serialized_start=8971
  _SETPLAYBACKMODERESPONSEBODY._serialized_end=9105
  _SETRECORDMODEREQUESTBODY._serialized_start=9107
  _SETRECORDMODEREQUESTBODY._serialized_end=9205
  _SETRECORDMODERESPONSEBODY._serialized_start=9207
  _SETRECORDMODERESPONSEBODY._serialized_end=9331
  _GETSESSIONAUDIOFORMATRESPONSEBODY._serialized_start=9334
  _GETSESSIONAUDIOFORMATRESPONSEBODY._serialized_end=9473
  _GETSESSIONSAMPLERATERESPONSEBODY._serialized_start=9475
  _GETSESSIONSAMPLERATERESPONSEBODY._serialized_end=9548
  _GETSESSIONBITDEPTHRESPONSEBODY._serialized_start=9550
  _GETSESSIONBITDEPTHRESPONSEBODY._serialized_end=9666
  _GETSESSIONINTERLEAVEDSTATERESPONSEBODY._serialized_start=9668
  _GETSESSIONINTERLEAVEDSTATERESPONSEBODY._serialized_end=9760
  _GETSESSIONTIMECODERATERESPONSEBODY._serialized_start=9763
  _GETSESSIONTIMECODERATERESPONSEBODY._serialized_end=9905
  _GETSESSIONFEETFRAMESRATERESPONSEBODY._serialized_start=9908
  _GETSESSIONFEETFRAMESRATERESPONSEBODY._serialized_end=10056
  _GETSESSIONAUDIORATEPULLSETTINGSRESPONSEBODY._serialized_start=10059
  _GETSESSIONAUDIORATEPULLSETTINGSRESPONSEBODY._serialized_end=10202
  _GETSESSIONVIDEORATEPULLSETTINGSRESPONSEBODY._serialized_start=10205
  _GETSESSIONVIDEORATEPULLSETTINGSRESPONSEBODY._serialized_end=10348
  _GETSESSIONNAMERESPONSEBODY._serialized_start=10350
  _GETSESSIONNAMERESPONSEBODY._serialized_end=10400
  _GETSESSIONPATHRESPONSEBODY._serialized_start=10402
  _GETSESSIONPATHRESPONSEBODY._serialized_end=10472
  _GETSESSIONSTARTTIMERESPONSEBODY._serialized_start=10474
  _GETSESSIONSTARTTIMERESPONSEBODY._serialized_end=10535
  _GETSESSIONLENGTHRESPONSEBODY._serialized_start=10537
  _GETSESSIONLENGTHRESPONSEBODY._serialized_end=10591
  _SETSESSIONAUDIOFORMATREQUESTBODY._serialized_start=10593
  _SETSESSIONAUDIOFORMATREQUESTBODY._serialized_end=10675
  _SETSESSIONBITDEPTHREQUESTBODY._serialized_start=10677
  _SETSESSIONBITDEPTHREQUESTBODY._serialized_end=10743
  _SETSESSIONINTERLEAVEDSTATEREQUESTBODY._serialized_start=10745
  _SETSESSIONINTERLEAVEDSTATEREQUESTBODY._serialized_end=10811
  _SETSESSIONTIMECODERATEREQUESTBODY._serialized_start=10813
  _SETSESSIONTIMECODERATEREQUESTBODY._serialized_end=10899
  _SETSESSIONFEETFRAMESRATEREQUESTBODY._serialized_start=10901
  _SETSESSIONFEETFRAMESRATEREQUESTBODY._serialized_end=10993
  _SETSESSIONAUDIORATEPULLSETTINGSREQUESTBODY._serialized_start=10995
  _SETSESSIONAUDIORATEPULLSETTINGSREQUESTBODY._serialized_end=11087
  _SETSESSIONVIDEORATEPULLSETTINGSREQUESTBODY._serialized_start=11089
  _SETSESSIONVIDEORATEPULLSETTINGSREQUESTBODY._serialized_end=11181
  _SETSESSIONSTARTTIMEREQUESTBODY._serialized_start=11184
  _SETSESSIONSTARTTIMEREQUESTBODY._serialized_end=11333
  _SETSESSIONLENGTHREQUESTBODY._serialized_start=11335
  _SETSESSIONLENGTHREQUESTBODY._serialized_end=11388
  _GETPTSLVERSIONRESPONSEBODY._serialized_start=11390
  _GETPTSLVERSIONRESPONSEBODY._serialized_end=11435
  _GETPLAYBACKMODERESPONSEBODY._serialized_start=11438
  _GETPLAYBACKMODERESPONSEBODY._serialized_end=11566
  _GETRECORDMODERESPONSEBODY._serialized_start=11568
  _GETRECORDMODERESPONSEBODY._serialized_end=11689
  _GETTRANSPORTSTATERESPONSEBODY._serialized_start=11692
  _GETTRANSPORTSTATERESPONSEBODY._serialized_end=11825
  _GETTRANSPORTARMEDRESPONSEBODY._serialized_start=11827
  _GETTRANSPORTARMEDRESPONSEBODY._serialized_end=11886
  _CLEARMEMORYLOCATIONREQUESTBODY._serialized_start=11888
  _CLEARMEMORYLOCATIONREQUESTBODY._serialized_end=11943
  _AUTHORIZECONNECTIONREQUESTBODY._serialized_start=11945
  _AUTHORIZECONNECTIONREQUESTBODY._serialized_end=11998
  _AUTHORIZECONNECTIONRESPONSEBODY._serialized_start=12000
  _AUTHORIZECONNECTIONRESPONSEBODY._serialized_end=12093
  _RENAMESELECTEDCLIPREQUESTBODY._serialized_start=12095
  _RENAMESELECTEDCLIPREQUESTBODY._serialized_end=12211
  _RENAMETARGETCLIPREQUESTBODY._serialized_start=12213
  _RENAMETARGETCLIPREQUESTBODY._serialized_end=12300
  _MEMORYLOCATION._serialized_start=12303
  _MEMORYLOCATION._serialized_end=12562
  _MEMORYLOCATIONPROPERTIES._serialized_start=12565
  _MEMORYLOCATIONPROPERTIES._serialized_end=12816
  _EDITMEMORYLOCATIONREQUESTBODY._serialized_start=12819
  _EDITMEMORYLOCATIONREQUESTBODY._serialized_end=13093
  _EDITMEMORYLOCATIONRESPONSEBODY._serialized_start=13095
  _EDITMEMORYLOCATIONRESPONSEBODY._serialized_end=13127
  _CREATEMEMORYLOCATIONREQUESTBODY._serialized_start=13130
  _CREATEMEMORYLOCATIONREQUESTBODY._serialized_end=13406
  _CREATEMEMORYLOCATIONRESPONSEBODY._serialized_start=13408
  _CREATEMEMORYLOCATIONRESPONSEBODY._serialized_end=13442
  _GETMEMORYLOCATIONSREQUESTBODY._serialized_start=13444
  _GETMEMORYLOCATIONSREQUESTBODY._serialized_end=13475
  _GETMEMORYLOCATIONSRESPONSEBODY._serialized_start=13477
  _GETMEMORYLOCATIONSRESPONSEBODY._serialized_end=13557
  _REGISTERCONNECTIONREQUESTBODY._serialized_start=13559
  _REGISTERCONNECTIONREQUESTBODY._serialized_end=13638
  _REGISTERCONNECTIONRESPONSEBODY._serialized_start=13640
  _REGISTERCONNECTIONRESPONSEBODY._serialized_end=13692
  _PTSL._serialized_start=22255
  _PTSL._serialized_end=22372
# @@protoc_insertion_point(module_scope)
